@@ -166,9 +166,9 @@ void KODayMatrix::recalculateToday()
         mDayLabels[i] = QString::number(mDays[i].day());
 
         // if today is in the currently displayed month, hilight today
-        if (mDays[i].year() == QDate::currentDate().year()
-            && mDays[i].month() == QDate::currentDate().month()
-            && mDays[i].day() == QDate::currentDate().day()) {
+        if (mDays[i].year() == QDate::currentDate().year() &&
+            mDays[i].month() == QDate::currentDate().month() &&
+            mDays[i].day() == QDate::currentDate().day()) {
             mToday = i;
         }
     }
@@ -280,10 +280,10 @@ void KODayMatrix::updateJournals()
     for (const KCalCore::Incidence::Ptr &inc : incidences) {
         Q_ASSERT(inc);
         QDate d = inc->dtStart().toLocalTime().date();
-        if (inc->type() == KCalCore::Incidence::TypeJournal
-            && d >= mDays[0]
-            && d <= mDays[NUMDAYS - 1]
-            && !mEvents.contains(d)) {
+        if (inc->type() == KCalCore::Incidence::TypeJournal &&
+            d >= mDays[0] &&
+            d <= mDays[NUMDAYS - 1] &&
+            !mEvents.contains(d)) {
             mEvents.append(d);
         }
         if (mEvents.count() == NUMDAYS) {
@@ -315,10 +315,11 @@ void KODayMatrix::updateTodos()
         if (t->hasDueDate()) {
             ushort recurType = t->recurrenceType();
 
-            if (t->recurs()
-                && !(recurType == KCalCore::Recurrence::rDaily && !KOPrefs::instance()->mDailyRecur)
-                && !(recurType == KCalCore::Recurrence::rWeekly
-                     && !KOPrefs::instance()->mWeeklyRecur)) {
+            if (t->recurs() &&
+                !(recurType == KCalCore::Recurrence::rDaily &&
+                  !KOPrefs::instance()->mDailyRecur) &&
+                !(recurType == KCalCore::Recurrence::rWeekly &&
+                  !KOPrefs::instance()->mWeeklyRecur)) {
                 // It's a recurring todo, find out in which days it occurs
                 const auto timeDateList
                     = t->recurrence()->timesInInterval(
@@ -367,9 +368,10 @@ void KODayMatrix::updateEvents()
         const int secsToAdd = event->allDay() ? 0 : -1;
         const QDateTime dtEnd = event->dtEnd().toLocalTime().addSecs(secsToAdd);
 
-        if (!(recurType == KCalCore::Recurrence::rDaily && !KOPrefs::instance()->mDailyRecur)
-            && !(recurType == KCalCore::Recurrence::rWeekly
-                 && !KOPrefs::instance()->mWeeklyRecur)) {
+        if (!(recurType == KCalCore::Recurrence::rDaily &&
+              !KOPrefs::instance()->mDailyRecur) &&
+            !(recurType == KCalCore::Recurrence::rWeekly &&
+              !KOPrefs::instance()->mWeeklyRecur)) {
             KCalCore::SortableList<QDateTime> timeDateList;
             const bool isRecurrent = event->recurs();
             const int eventDuration = dtStart.daysTo(dtEnd);
@@ -429,9 +431,8 @@ QString KODayMatrix::getHolidayLabel(int offset) const
 
 int KODayMatrix::getDayIndexFrom(int x, int y) const
 {
-    return 7 * (y / mDaySize.height())
-           +(KOGlobals::self()->reverseLayout()
-             ? 6 - x / mDaySize.width() : x / mDaySize.width());
+    return 7 * (y / mDaySize.height()) +
+        (KOGlobals::self()->reverseLayout() ? 6 - x / mDaySize.width() : x / mDaySize.width());
 }
 
 void KODayMatrix::calendarIncidenceAdded(const KCalCore::Incidence::Ptr &incidence)
@@ -458,9 +459,9 @@ void KODayMatrix::setHighlightMode(bool highlightEvents, bool highlightTodos,
                                    bool highlightJournals)
 {
     // don't set mPendingChanges to true if nothing changed
-    if (highlightTodos != mHighlightTodos
-        || highlightEvents != mHighlightEvents
-        || highlightJournals != mHighlightJournals) {
+    if (highlightTodos != mHighlightTodos ||
+        highlightEvents != mHighlightEvents ||
+        highlightJournals != mHighlightJournals) {
         mHighlightEvents = highlightEvents;
         mHighlightTodos = highlightTodos;
         mHighlightJournals = highlightJournals;
@@ -751,11 +752,11 @@ void KODayMatrix::paintEvent(QPaintEvent *)
         if (row < 6 && row >= 0) {
             if (row == mSelEnd / 7) {
                 // Single row selection
-                p.fillRect(isRTL
-                           ? (7 - (mSelEnd - mSelStart + 1) - column) * dayWidth
-                           : column * dayWidth,
-                           row * dayHeight,
-                           (mSelEnd - mSelStart + 1) * dayWidth, dayHeight, selectionColor);
+                p.fillRect(
+                    isRTL ?
+                        (7 - (mSelEnd - mSelStart + 1) - column) * dayWidth : column * dayWidth,
+                    row * dayHeight,
+                    (mSelEnd - mSelStart + 1) * dayWidth, dayHeight, selectionColor);
             } else {
                 // draw first row to the right
                 p.fillRect(isRTL ? 0 : column * dayWidth, row * dayHeight,
@@ -772,9 +773,7 @@ void KODayMatrix::paintEvent(QPaintEvent *)
                 // draw last block from left to mSelEnd
                 if (mSelEnd / 7 < 6) {
                     int selectionWidth = mSelEnd - 7 * (mSelEnd / 7) + 1;
-                    p.fillRect(isRTL
-                               ? (7 - selectionWidth) * dayWidth
-                               : 0,
+                    p.fillRect(isRTL ? (7 - selectionWidth) * dayWidth : 0,
                                (row + selectionHeight) * dayHeight,
                                selectionWidth * dayWidth, dayHeight, selectionColor);
                 }
@@ -893,7 +892,7 @@ QPair<QDate, QDate> KODayMatrix::matrixLimits(const QDate &month)
     QDate d(month.year(), month.month(), 1);
 
     const int dayOfWeek = d.dayOfWeek();
-    const int weekstart = QLocale().firstDayOfWeek();
+    const int weekstart = KOGlobals::self()->firstDayOfWeek();
 
     d = d.addDays(-(7 + dayOfWeek - weekstart) % 7);
 
